summaryrefslogtreecommitdiffstats
path: root/src/usr/hwas/common/hwas.C
diff options
context:
space:
mode:
authorMatt Derksen <mderkse1@us.ibm.com>2017-09-13 08:58:27 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-10-15 16:26:48 -0400
commita5d19110fd5dad891f8fe20c260fb7fb23051822 (patch)
treeeeeecdc372c8e6294fa74ed152e981b5c680fd20 /src/usr/hwas/common/hwas.C
parent54a809824656603dad56d67c8cab8946bfa43ecb (diff)
downloadtalos-hostboot-a5d19110fd5dad891f8fe20c260fb7fb23051822.tar.gz
talos-hostboot-a5d19110fd5dad891f8fe20c260fb7fb23051822.zip
Fix parent of OBUS_BRICK
- remove OPTICS_CONFIG_MODE from obus brick targets - remove FAPI_POS from cumulus obus bricks Change-Id: I7248bcf39526378fa5b8322a331beeeb33d4d2a4 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/46141 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Reviewed-by: Prachi Gupta <pragupta@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/hwas/common/hwas.C')
-rw-r--r--src/usr/hwas/common/hwas.C10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/usr/hwas/common/hwas.C b/src/usr/hwas/common/hwas.C
index c2636baf7..c8af71942 100644
--- a/src/usr/hwas/common/hwas.C
+++ b/src/usr/hwas/common/hwas.C
@@ -1066,8 +1066,13 @@ bool isDescFunctional(const TARGETING::TargetHandle_t &i_desc,
else
if (i_desc->getAttr<ATTR_TYPE>() == TYPE_OBUS_BRICK)
{
- //If NPU is bad and Bricks are non-SMP, then mark them bad
- if ((i_desc->getAttr<ATTR_OPTICS_CONFIG_MODE>()
+ auto obusType = TARGETING::TYPE_OBUS;
+ TARGETING::Target* l_obus_ptr = const_cast<TARGETING::Target*>(
+ getParent(i_desc, obusType));
+
+ //If NPU is bad and OBUS is non-SMP, then mark them bad
+ // Bit does not matter unless not in SMP mode
+ if ((l_obus_ptr->getAttr<ATTR_OPTICS_CONFIG_MODE>()
!= OPTICS_CONFIG_MODE_SMP) &&
((i_pgData[VPD_CP00_PG_N3_INDEX] & VPD_CP00_PG_N3_NPU) != 0))
{
@@ -1079,7 +1084,6 @@ bool isDescFunctional(const TARGETING::TargetHandle_t &i_desc,
(i_pgData[VPD_CP00_PG_N3_INDEX] &
~VPD_CP00_PG_N3_NPU));
l_descFunctional = false;
-
}
}
else
OpenPOWER on IntegriCloud